.. nadzoring documentation master file

Welcome to Nadzoring's documentation!
======================================

**Nadzoring** (from Russian "надзор" - supervision/oversight + English "-ing" suffix)
is a FOSS (Free and Open Source Software) command-line tool for detecting website blocks,
monitoring service availability, and network analysis.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   quickstart
   commands/index
   api/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
